@@ -5,6 +5,7 @@ a 'minified' representation of the same source code.
 """
 
 import ast
+import re
 
 from python_minifier.ast_compare import CompareError, compare_ast
 from python_minifier.module_printer import ModulePrinter
@@ -57,7 +58,8 @@ def minify(
     rename_globals=False,
     preserve_globals=None,
     remove_object_base=True,
-    convert_posargs_to_args=True
+    convert_posargs_to_args=True,
+    preserve_shebang=True
 ):
     """
     Minify a python module
@@ -83,6 +85,8 @@ def minify(
     :param preserve_globals: Global names to leave unchanged when rename_globals is True
     :type preserve_globals: list[str]
     :param bool remove_object_base: If object as a base class may be removed
+    :param bool convert_posargs_to_args: If positional-only arguments will be converted to normal arguments
+    :param bool preserve_shebang: Keep any shebang interpreter directive from the source in the minified output
 
     :rtype: str
 
@@ -128,8 +132,30 @@ def minify(
     if convert_posargs_to_args:
         module = remove_posargs(module)
 
-    return unparse(module)
+    minified = unparse(module)
 
+    if preserve_shebang is True:
+        shebang_line = _find_shebang(source)
+        if shebang_line is not None:
+            return shebang_line + '\n' + minified
+
+    return minified
+
+def _find_shebang(source):
+    """
+    Find a shebang line in source
+    """
+
+    if isinstance(source, bytes):
+        shebang = re.match(br'^#!.*', source)
+        if shebang:
+            return shebang.group().decode()
+    else:
+        shebang = re.match(r'^#!.*', source)
+        if shebang:
+            return shebang.group()
+
+    return None
 
 def unparse(module):
     """
@@ -182,9 +208,5 @@ def awslambda(source, filename=None, entrypoint=None):
         rename_globals = False
 
     return minify(
-        source,
-        filename,
-        remove_literal_statements=True,
-        rename_globals=rename_globals,
-        preserve_globals=[entrypoint],
+        source, filename, remove_literal_statements=True, rename_globals=rename_globals, preserve_globals=[entrypoint],
     )
